summaryrefslogtreecommitdiff
path: root/lib/os_internal.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/os_internal.h')
-rw-r--r--lib/os_internal.h14
1 files changed, 10 insertions, 4 deletions
diff --git a/lib/os_internal.h b/lib/os_internal.h
index 6d5d33ae4..f7365381f 100644
--- a/lib/os_internal.h
+++ b/lib/os_internal.h
@@ -84,11 +84,17 @@ char *_xine_private_strpbrk(const char *s, const char *accept);
char *_xine_private_strsep(char **stringp, const char *delim);
#endif
/* replacement of gmtime */
#ifndef HAVE_GMTIME
#include <time.h>
-#define gmtime(TM) _xine_private_gmtime((TM))
-time_t _xine_private_gmtime(struct tm *tm);
+#define timegm(TM) _xine_private_timegm((TM))
+time_t _xine_private_timegm(struct tm *tm);
+#endif
+
+/* replacement of unsetenv */
+#ifndef HAVE_UNSETENV
+#define unsetenv(NAME) _xine_private_unsetenv((NAME))
+void _xine_private_unsetenv(const char *name);
#endif
/* macross needed for MSVC */
@@ -84,11 +84,17 @@ char *_xine_private_strpbrk(const char *s, const char *accept);
char *_xine_private_strsep(char **stringp, const char *delim);
#endif
-/* replacement of gmtime */
-#ifndef HAVE_GMTIME
+/* replacement of timegm */
+#ifndef HAVE_TIMEGM
#include <time.h>